SystemOrganization addCategory: #'RSS-Tests-Core'!

!GRPackage class methodsFor: '*rss-tests-core' stamp: 'pmm 8/14/2010 11:47'!
rssTestsCore
	^ self new
		name: 'RSS-Tests-Core';
		description: 'Unit tests for the "RSS-Core" package.';
		addDependency: 'RSS-Core';
		addDependency: 'Seaside-Tests-Core';
		url: #seasideUrl;
		yourself! !

RRComponent subclass: #RRTestComponent
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RSS-Tests-Core'!

!RRTestComponent methodsFor: 'rendering' stamp: 'pmm 8/14/2010 11:53'!
renderContentOn: rss
	"do nothing"! !

!RRTestComponent methodsFor: 'updating' stamp: 'pmm 8/14/2010 11:45'!
updateRoot: anRssRoot
	super updateRoot: anRssRoot.
	anRssRoot stylesheet beXsl
		url: 'http://www.seaside.st/feed.xsl'! !

WAContextTest subclass: #RRComponentRenderingTest
	instanceVariableNames: 'handler'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RSS-Tests-Core'!

!RRComponentRenderingTest methodsFor: 'configuration' stamp: 'pmm 8/14/2010 11:50'!
createHandlers
	^Array with: handler! !

!RRComponentRenderingTest methodsFor: 'running' stamp: 'pmm 8/14/2010 11:52'!
setUp
	handler := RRRssHandler new
		rootComponentClass: RRTestComponent;
		yourself! !

!RRComponentRenderingTest methodsFor: 'testing' stamp: 'pmm 8/14/2010 11:58'!
testUpdateRoot
	 | response |
	[ handler handleFiltered: self requestContext ]
		on: WAResponseNotification
		do: [ :notification | "ignore" ].
	response := self requestContext response.
	self assert: response status = 200.
	self assert: '<?xml version="1.0" encoding="utf-8"?>',
		'<?xml-stylesheet type="text/xsl" href="http://www.seaside.st/feed.xsl"?>',
		'<rss version="2.0" xmlns:content="http://purl.org/rss/1.0/modules/content/" xmlns:wfw="http://wellformedweb.org/CommentAPI/" xmlns:dc="http://purl.org/dc/elements/1.1/">',
		'<channel></channel></rss>' = response contents! !

WAContextTest subclass: #RRComponentTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RSS-Tests-Core'!

!RRComponentTest methodsFor: 'testing' stamp: 'pmm 12/19/2010 12:09'!
testCanBeRoot
	self deny: RRComponent canBeRoot.
	self assert: RRTestComponent canBeRoot! !

TestCase subclass: #RRRenderTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RSS-Tests-Core'!

!RRRenderTest class methodsFor: 'accessing' stamp: 'lr 9/9/2010 12:25'!
packageNamesUnderTest
	^ #('RSS-Core')! !

!RRRenderTest methodsFor: 'running' stamp: 'jf 9/30/2009 00:27'!
performTest
	| context |
	context := WARequestContext 
		request: nil
		response: nil
		codec: GRNullCodec new.
	WACurrentRequestContext 
		use: context
		during: [ super performTest ]! !

!RRRenderTest methodsFor: 'private' stamp: 'jf 2/15/2009 21:05'!
render: aBlock
	^ RRRssRenderCanvas builder render: aBlock! !

!RRRenderTest methodsFor: 'private' stamp: 'pmm 5/31/2008 18:47'!
renderFull: aBlock
	^self renderFull: aBlock rootBlock: nil! !

!RRRenderTest methodsFor: 'private' stamp: 'jf 2/15/2009 21:05'!
renderFull: aBlock rootBlock: anObject
	^RRRssRenderCanvas builder
		fullDocument: true;
		rootBlock: anObject;
		render: aBlock! !

!RRRenderTest methodsFor: 'tests' stamp: 'pmm 1/1/2009 18:50'!
testEmail
	| actual expected |
	actual := self render: [ :rss |
		rss author: (WAEmailAddress address: 'joesmith@example.com' username: 'Joe Smith') ].
	expected := '<author>Joe Smith &lt;joesmith@example.com&gt;</author>'.
	self assert: actual = expected! !

!RRRenderTest methodsFor: 'tests' stamp: 'lr 2/8/2009 15:44'!
testExample
	| actualContent expectedContent |
	actualContent := self render: [ :rss |
		rss description: 'Das super geile Blog.'.
		rss contentEncoded: '<p>Das super geile Blog.</p>'.
		rss generator: 'Pier 1.0.9-alpha'.
		rss language english ].
	expectedContent := '<description>Das super geile Blog.</description><content:encoded><!![CDATA[<p>Das super geile Blog.</p>]]></content:encoded><generator>Pier 1.0.9-alpha</generator><language>en</language>'.
	self assert: actualContent = expectedContent! !

!RRRenderTest methodsFor: 'tests' stamp: 'lr 2/8/2009 15:44'!
testRenderExample
	| actualContent expectedContent |
	actualContent := self render: [ :rss |
		rss description: 'Das super geile Blog.'.
		rss renderContentEncoded: [ :html |
			html paragraph:  'Das super geile Blog.' ].
		rss generator: 'Pier 1.0.9-alpha'.
		rss language english ].
	expectedContent := '<description>Das super geile Blog.</description><content:encoded>&lt;p&gt;Das super geile Blog.&lt;/p&gt;</content:encoded><generator>Pier 1.0.9-alpha</generator><language>en</language>'.
	self assert: actualContent = expectedContent! !

!RRRenderTest methodsFor: 'tests' stamp: 'pmm 9/20/2009 14:33'!
testRenderExampleFull
	| actualContent expectedContent |
	actualContent := self
		renderFull: [ :rss |
			rss description: 'Das super geile Blog.'.
			rss renderContentEncoded: [ :html |
				html paragraph:  'Das super geile Blog.' ].
			rss generator: 'Pier 1.0.9-alpha'.
			rss language english ]
		rootBlock: [ :root |
			root stylesheet beCss; url: 'http://yourserver.com/path/rss.css' ].
	
	expectedContent := '<?xml version="1.0" encoding="UTF-8"?><?xml-stylesheet type="text/css" href="http://yourserver.com/path/rss.css"?><rss version="2.0" xmlns:content="http://purl.org/rss/1.0/modules/content/" xmlns:wfw="http://wellformedweb.org/CommentAPI/" xmlns:dc="http://purl.org/dc/elements/1.1/"><channel><description>Das super geile Blog.</description><content:encoded>&lt;p&gt;Das super geile Blog.&lt;/p&gt;</content:encoded><generator>Pier 1.0.9-alpha</generator><language>en</language></channel></rss>'.
	self assert: actualContent = expectedContent! !

!RRRenderTest methodsFor: 'tests' stamp: 'jok 6/28/2010 14:00'!
testWithLineBreaks
	| actualContent expectedContent |
	actualContent := self render: [ :rss |
		rss withLineBreaks: 'das', GRPlatform current newline, 'super', GRPlatform current newline, 'geile', GRPlatform current newline, 'Blog' ].
	expectedContent := 'das&lt;br/&gt;super&lt;br/&gt;geile&lt;br/&gt;Blog'.
	self assert: actualContent = expectedContent! !

TestCase subclass: #RRRfc822DateTimeTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RSS-Tests-Core'!

!RRRfc822DateTimeTest methodsFor: 'private' stamp: 'jf 2/15/2009 21:01'!
render: anObject
	^ RRRssRenderCanvas builder render: anObject! !

!RRRfc822DateTimeTest methodsFor: 'tests' stamp: 'pmm 8/31/2008 20:23'!
testNewDateAndTime
	| date emailDate |
	date := DateAndTime year: 2008 month: 8 day: 1 hour: 9 minute: 4 second: 4 offset: (Duration days: 0 hours: 2 minutes: 0 seconds: 0).
	emailDate := RRRfc822DateTime newDateAndTime: date.
	self assert: 'Fri, 01 Aug 2008 09:04:04 +0200' = (self render: emailDate)! !

!RRRfc822DateTimeTest methodsFor: 'tests' stamp: 'jgf 2/3/2009 10:38'!
testNewDateAndTimeTimezoneString
	| date emailDate |
	date := DateAndTime year: 2008 month: 8 day: 31 hour: 19 minute: 14 second: 24 offset: Duration zero.
	emailDate := RRRfc822DateTime
		newDateAndTime: date
		offset: (Duration days: 0 hours: -2 minutes: 0 seconds: 0).
	self assert: 'Sun, 31 Aug 2008 19:14:24 -0200' = (self render: emailDate)! !

!RRRfc822DateTimeTest methodsFor: 'tests' stamp: 'pmm 8/31/2008 19:31'!
testNewDateAndTimeUtc
	| date emailDate |
	date := DateAndTime year: 2008 month: 8 day: 31 hour: 19 minute: 14 second: 24 offset: (Duration days: 0 hours: 2 minutes: 0 seconds: 0).
	emailDate := RRRfc822DateTime newUtc: date.
	self assert: 'Sun, 31 Aug 2008 17:14:24 UT' = (self render: emailDate)! !

!RRRfc822DateTimeTest methodsFor: 'tests' stamp: 'jok 4/20/2010 08:23'!
testOffsetString
	| duration formatted |
	duration := Duration days: 0 hours: 2 minutes: 3 seconds: 0.
	formatted := RRRfc822DateTime offsetString: duration.
	self assert: '+0203' = formatted.
	
	duration := Duration days: 0 hours: -2 minutes: 0 seconds: 0.
	formatted := RRRfc822DateTime offsetString: duration.
	self assert: '-0200' = formatted.
	
	duration := Duration days: 0 hours: 0 minutes: -3 seconds: 0.
	formatted := RRRfc822DateTime offsetString: duration.
	self assert: '-0003' = formatted.
	
	"Test that 0 offset is positive and #offsetString: sends only ANSI messages."
	duration:= Duration zero.
	formatted := RRRfc822DateTime offsetString: duration.
	self assert: '+0000' = formatted! !
